@@ -4,13 +4,6 @@ from dotnetz.runtime import *
 P = ParamSpec("P")
 T = TypeVar("T")
 
-def delegate(f: Callable[P, T]) -> Callable[P, T]:
-  @wraps(f)
-  def inner(*args: P.args, **kwargs: P.kwargs) -> T:
-    # await log_to_database()
-    return f(*args, **kwargs)
-  return inner
-
 class EventHandler(Generic[T, P]):
   handlers: List[Callable[P, T]]
 
@@ -48,11 +41,13 @@ class EventHandler(Generic[T, P]):
     except ValueError:
       pass
 
-  def __iadd__(self, callback: Callable[P, T]):
-    return self.add(callback)
+  def __iadd__(self, callback: Callable[P, T]) -> EventHandler:
+    self.add(callback)
+    return self
 
-  def __isub__(self, callback: Callable[P, T]):
-    return self.remove(callback)
+  def __isub__(self, callback: Callable[P, T]) -> EventHandler:
+    self.remove(callback)
+    return self
 
   def __contains__(self, callback: Callable[P, T]):
     return callback in self.handlers
